<template>
  <SettingsLayout :title="data.title">
    <ActionToolBar :toolbar="toolbar" />
    <SearchBar :hide_inactive_search="true" :url="data.urls.search" :filters="filters.filters" />

    <Table :options="tableOptions" :links="questions.links" :total="questions.total">
      <template v-slot>
        <tr v-for="(question, index) in questions.data" :key="index">
          <td>            
            <Link
              :href="route('admin.settings.authorAssessment.writingTopic.edit', question.uuid)"
              >{{ question.topic_text }}</Link
            >
          </td>
          <td class="col-md-2 text-end">
            <DestroyButton
              :delete_url="
                route('admin.settings.authorAssessment.writingTopic.destroy', question.uuid)
              "
            />
          </td>
        </tr>
      </template>
    </Table>
  </SettingsLayout>
</template>

<script>
import SettingsLayout from "../../Partials/SettingsLayout.vue";
import SearchBar from "../../../../../Shared/SearchBar.vue";
import ActionToolBar from "../../Partials/ActionToolBar.vue";
import DestroyButton from "../../../../../components/Form/DestroyButton.vue";

import Table from "../../../../../components/Table.vue";

export default {
  components: {
    SettingsLayout,
    SearchBar,
    Table,
    ActionToolBar,
    DestroyButton,
  },
  props: ["data", "questions", "filters"],
  data() {
    return {
      toolbar: {
        title: this.data.title,
        hide_save_button: true,
        links: {
          create: {
            title: this.data.create_link_text,
            url: this.data.urls.new_item,
          },
        },
      },
      tableOptions: {
        titles: [
          {
            name: this.__("Title"),
            className: "col-md-6",
          },
          {
            name: this.__("Action"),
            className: "col-md-1 text-end",
          },
        ],
      },
    };
  },
};
</script>
